diff --git a/Library/Homebrew/brew.sh b/Library/Homebrew/brew.sh
index 70a23a39c3940c9b0c902a10a5ae8c090c42cd4f..0fadecaba39687071160feda027608016d46a673 100644
--- a/Library/Homebrew/brew.sh
+++ b/Library/Homebrew/brew.sh
@@ -70,23 +70,23 @@ unset BASH_ENV
 
 HOMEBREW_SYSTEM="$(uname -s)"
 case "$HOMEBREW_SYSTEM" in
-  Darwin) HOMEBREW_OSX="1" ;;
+  Darwin) HOMEBREW_MACOS="1" ;;
   Linux)  HOMEBREW_LINUX="1" ;;
 esac
 
 HOMEBREW_CURL="/usr/bin/curl"
-if [[ -n "$HOMEBREW_OSX" ]]
+if [[ -n "$HOMEBREW_MACOS" ]]
 then
   HOMEBREW_PROCESSOR="$(uname -p)"
   HOMEBREW_PRODUCT="Homebrew"
   HOMEBREW_SYSTEM="Macintosh"
   # This is i386 even on x86_64 machines
   [[ "$HOMEBREW_PROCESSOR" = "i386" ]] && HOMEBREW_PROCESSOR="Intel"
-  HOMEBREW_OSX_VERSION="$(/usr/bin/sw_vers -productVersion)"
-  HOMEBREW_OS_VERSION="Mac OS X $HOMEBREW_OSX_VERSION"
+  HOMEBREW_MACOS_VERSION="$(/usr/bin/sw_vers -productVersion)"
+  HOMEBREW_OS_VERSION="macOS $HOMEBREW_MACOS_VERSION"
 
-  printf -v HOMEBREW_OSX_VERSION_NUMERIC "%02d%02d%02d" ${HOMEBREW_OSX_VERSION//./ }
-  if [[ "$HOMEBREW_OSX_VERSION_NUMERIC" -lt "100900" &&
+  printf -v HOMEBREW_MACOS_VERSION_NUMERIC "%02d%02d%02d" ${HOMEBREW_MACOS_VERSION//./ }
+  if [[ "$HOMEBREW_MACOS_VERSION_NUMERIC" -lt "100900" &&
         -x "$HOMEBREW_PREFIX/opt/curl/bin/curl" ]]
   then
     HOMEBREW_CURL="$HOMEBREW_PREFIX/opt/curl/bin/curl"
@@ -121,11 +121,11 @@ export HOMEBREW_CURL
 export HOMEBREW_PROCESSOR
 export HOMEBREW_PRODUCT
 export HOMEBREW_OS_VERSION
-export HOMEBREW_OSX_VERSION
+export HOMEBREW_MACOS_VERSION
 export HOMEBREW_USER_AGENT
 export HOMEBREW_USER_AGENT_CURL
 
-if [[ -n "$HOMEBREW_OSX" ]]
+if [[ -n "$HOMEBREW_MACOS" ]]
 then
   XCODE_SELECT_PATH=$('/usr/bin/xcode-select' --print-path 2>/dev/null)
   if [[ "$XCODE_SELECT_PATH" = "/" ]]
@@ -224,7 +224,7 @@ check-run-command-as-root() {
   onoe <<EOS
 Running Homebrew as root is extremely dangerous. As Homebrew does not
 drop privileges on installation you are giving all build scripts full access
-to your system. As a result of the OS X sandbox not handling the root user
+to your system. As a result of the macOS sandbox not handling the root user
 correctly HOMEBREW_NO_SANDBOX has been set so the sandbox will not be used. If
 we have not merged a pull request to add privilege dropping by November 1st
 2016 running Homebrew as root will be disabled. No Homebrew maintainers plan
diff --git a/Library/Homebrew/cmd/fetch.rb b/Library/Homebrew/cmd/fetch.rb
index 93141ca5b86572e2eed5474b6eb2700562edc5d2..9c42eda23660a5df1b503bde015392e49a156aeb 100644
--- a/Library/Homebrew/cmd/fetch.rb
+++ b/Library/Homebrew/cmd/fetch.rb
@@ -19,7 +19,7 @@
 #:    bottle.
 #:
 #:    If `--force-bottle` is passed, download a bottle if it exists for the current
-#:    version of OS X, even if it would not be used during installation.
+#:    version of macOS, even if it would not be used during installation.
 
 require "formula"
 
diff --git a/Library/Homebrew/cmd/install.rb b/Library/Homebrew/cmd/install.rb
index 99cb7535303f9ae3b9a343d92b060c9ecab3f39d..b2b3eb7c07b25903d81f8d792d32f16f9d0aff02 100644
--- a/Library/Homebrew/cmd/install.rb
+++ b/Library/Homebrew/cmd/install.rb
@@ -34,7 +34,7 @@
 #:
 #     Hidden developer option:
 #     If `--force-bottle` is passed, install from a bottle if it exists
-#    for the current version of OS X, even if custom options are given.
+#    for the current version of macOS, even if custom options are given.
 #
 #:    If `--devel` is passed, and <formula> defines it, install the development version.
 #:
diff --git a/Library/Homebrew/cmd/linkapps.rb b/Library/Homebrew/cmd/linkapps.rb
index a4e4326f29684a2b8636f45c3a27083054646f13..c7685855f32d08184e21151657a42a644318465f 100644
--- a/Library/Homebrew/cmd/linkapps.rb
+++ b/Library/Homebrew/cmd/linkapps.rb
@@ -1,5 +1,5 @@
 #:  * `linkapps` [`--local`] [<formulae>]:
-#:    Find installed formulae that provide `.app`-style OS X apps and symlink them
+#:    Find installed formulae that provide `.app`-style macOS apps and symlink them
 #:    into `/Applications`, allowing for easier access.
 #:
 #:    If no <formulae> are provided, all of them will have their apps symlinked.
diff --git a/Library/Homebrew/cmd/update.sh b/Library/Homebrew/cmd/update.sh
index 8f02579c379c3b4697a1dc2ea9d7e00498dd5a8b..b57691893c5dc34250249efa3134cb6b7cc368f2 100644
--- a/Library/Homebrew/cmd/update.sh
+++ b/Library/Homebrew/cmd/update.sh
@@ -23,7 +23,7 @@ git() {
 }
 
 git_init_if_necessary() {
-  if [[ -n "$HOMEBREW_OSX" ]]
+  if [[ -n "$HOMEBREW_MACOS" ]]
   then
     BREW_OFFICIAL_REMOTE="https://github.com/Homebrew/brew"
     CORE_OFFICIAL_REMOTE="https://github.com/Homebrew/homebrew-core"
diff --git a/Library/Homebrew/cmd/vendor-install.sh b/Library/Homebrew/cmd/vendor-install.sh
index ca64789bced5d878c36e23b7499d0b4e0d3ed242..8f08e49fb0e5297979724e2007331efdf6c7cc6e 100644
--- a/Library/Homebrew/cmd/vendor-install.sh
+++ b/Library/Homebrew/cmd/vendor-install.sh
@@ -9,7 +9,7 @@ source "$HOMEBREW_LIBRARY/Homebrew/utils/lock.sh"
 VENDOR_DIR="$HOMEBREW_LIBRARY/Homebrew/vendor"
 
 # Built from https://github.com/Homebrew/homebrew-portable.
-if [[ -n "$HOMEBREW_OSX" ]]
+if [[ -n "$HOMEBREW_MACOS" ]]
 then
   if [[ "$HOMEBREW_PROCESSOR" = "Intel" ]]
   then
diff --git a/Library/Homebrew/dev-cmd/bottle.rb b/Library/Homebrew/dev-cmd/bottle.rb
index 1a7da8eb9c1ac98557513c0698da74f804b374f5..ab2735adb554481f4441a4817e59358e53578604 100644
--- a/Library/Homebrew/dev-cmd/bottle.rb
+++ b/Library/Homebrew/dev-cmd/bottle.rb
@@ -31,8 +31,8 @@ BOTTLE_ERB = <<-EOS.freeze
     <% end %>
     <% checksums.each do |checksum_type, checksum_values| %>
     <% checksum_values.each do |checksum_value| %>
-    <% checksum, osx = checksum_value.shift %>
-    <%= checksum_type %> "<%= checksum %>" => :<%= osx %>
+    <% checksum, macos = checksum_value.shift %>
+    <%= checksum_type %> "<%= checksum %>" => :<%= macos %>
     <% end %>
     <% end %>
   end
diff --git a/Library/Homebrew/diagnostic.rb b/Library/Homebrew/diagnostic.rb
index bcdde665612e2d1faf6b0a4fb8d041ccdd7a7a1e..650ff3eab51884b877b2828aeb45b707a50d5f1f 100644
--- a/Library/Homebrew/diagnostic.rb
+++ b/Library/Homebrew/diagnostic.rb
@@ -554,7 +554,7 @@ module Homebrew
             Homebrew doesn't provide a libiconv formula, and expects to link against
             the system version in /usr. libiconv in other prefixes can cause
             compile or link failure, especially if compiled with improper
-            architectures. OS X itself never installs anything to /usr/local so
+            architectures. macOS itself never installs anything to /usr/local so
             it was either installed by a user or some other third party software.
 
             tl;dr: delete these files:
@@ -659,7 +659,7 @@ module Homebrew
 
         <<-EOS.undent
           Your Cellar and TEMP directories are on different volumes.
-          OS X won't move relative symlinks across volumes unless the target file already
+          macOS won't move relative symlinks across volumes unless the target file already
           exists. Brews known to be affected by this are Git and Narwhal.
 
           You should set the "HOMEBREW_TEMP" environmental variable to a suitable
@@ -696,7 +696,7 @@ module Homebrew
 
         <<-EOS.undent
           The filesystem on #{case_sensitive_vols.join(",")} appears to be case-sensitive.
-          The default OS X filesystem is case-insensitive. Please report any apparent problems.
+          The default macOS filesystem is case-insensitive. Please report any apparent problems.
         EOS
       end
 
diff --git a/Library/Homebrew/exceptions.rb b/Library/Homebrew/exceptions.rb
index 70045333a90f537bcce9300d1434a7a013b32e17..07658c6e7f705ccea54535f6f72f6ff61d5c2fb1 100644
--- a/Library/Homebrew/exceptions.rb
+++ b/Library/Homebrew/exceptions.rb
@@ -356,8 +356,8 @@ class BuildError < RuntimeError
     end
 
     require "diagnostic"
-    unsupported_osx = Homebrew::Diagnostic::Checks.new.check_for_unsupported_osx
-    opoo unsupported_osx if unsupported_osx
+    unsupported_macos = Homebrew::Diagnostic::Checks.new.check_for_unsupported_macos
+    opoo unsupported_macos if unsupported_macos
   end
 end
 
diff --git a/Library/Homebrew/extend/os/mac/diagnostic.rb b/Library/Homebrew/extend/os/mac/diagnostic.rb
index f8d6c9e1f960b9ed2429bd0983408437b3f24dda..15dd3328fe718304d6741c58e06459fddbd75c32 100644
--- a/Library/Homebrew/extend/os/mac/diagnostic.rb
+++ b/Library/Homebrew/extend/os/mac/diagnostic.rb
@@ -3,7 +3,7 @@ module Homebrew
     class Checks
       def development_tools_checks
         %w[
-          check_for_unsupported_osx
+          check_for_unsupported_macos
           check_for_prerelease_xcode
           check_for_bad_install_name_tool
           check_for_installed_developer_tools
@@ -25,7 +25,7 @@ module Homebrew
         end
       end
 
-      def check_for_unsupported_osx
+      def check_for_unsupported_macos
         return if ARGV.homebrew_developer?
 
         who = "We"
@@ -39,7 +39,7 @@ module Homebrew
         end
 
         <<-EOS.undent
-          You are using OS X #{MacOS.version}.
+          You are using macOS #{MacOS.version}.
           #{who} do not provide support for this #{what}.
           You may encounter build failures or other breakages.
           Please create pull-requests instead of filing issues.
@@ -98,7 +98,7 @@ module Homebrew
 
         <<-EOS.undent
           You have Xcode 8 installed without the CLT;
-          this causes certain builds to fail on OS X 10.11.
+          this causes certain builds to fail on OS X El Capitan (10.11).
           Please install the CLT via:
             sudo xcode-select --install
         EOS
@@ -150,7 +150,7 @@ module Homebrew
           You have an outdated version of /usr/bin/install_name_tool installed.
           This will cause binary package installations to fail.
           This can happen if you install osx-gcc-installer or RailsInstaller.
-          To restore it, you must reinstall OS X or restore the binary from
+          To restore it, you must reinstall macOS or restore the binary from
           the OS packages.
         EOS
       end
diff --git a/Library/Homebrew/extend/os/mac/system_config.rb b/Library/Homebrew/extend/os/mac/system_config.rb
index c369f38e6b88179280b5b84b3b895e557aaa453a..acee50ad0cd99b4bda166884e8b50d9ad0721498 100644
--- a/Library/Homebrew/extend/os/mac/system_config.rb
+++ b/Library/Homebrew/extend/os/mac/system_config.rb
@@ -40,7 +40,7 @@ class SystemConfig
 
     def dump_verbose_config(f = $stdout)
       dump_generic_verbose_config(f)
-      f.puts "OS X: #{MacOS.full_version}-#{kernel}"
+      f.puts "macOS: #{MacOS.full_version}-#{kernel}"
       f.puts "Xcode: #{xcode ? xcode : "N/A"}"
       f.puts "CLT: #{clt ? clt : "N/A"}"
       f.puts "X11: #{describe_xquartz}"
diff --git a/Library/Homebrew/formula.rb b/Library/Homebrew/formula.rb
index 599b4939204339a902e047e4925f7eff898bf21f..f40f541104e558c311b50c57c1a6ba04a29b7ab0 100644
--- a/Library/Homebrew/formula.rb
+++ b/Library/Homebrew/formula.rb
@@ -1988,7 +1988,7 @@ class Formula
     # depends_on :fortran # Checks that `gfortran` is available or `FC` is set.
     # depends_on :mpi => :cc # Needs MPI with `cc`
     # depends_on :mpi => [:cc, :cxx, :optional] # Is optional. MPI with `cc` and `cxx`.
-    # depends_on :macos => :lion # Needs at least Mac OS X "Lion" aka. 10.7.
+    # depends_on :macos => :lion # Needs at least OS X Lion (10.7).
     # depends_on :apr # If a formula requires the CLT-provided apr library to exist.
     # depends_on :arch => :intel # If this formula only builds on Intel architecture.
     # depends_on :arch => :x86_64 # If this formula only builds on Intel x86 64-bit.
@@ -2004,7 +2004,7 @@ class Formula
     # depends_on :postgresql if build.without? "sqlite"
     # depends_on :hg # Mercurial (external or brewed) is needed</pre>
     #
-    # <pre># If any Python >= 2.7 < 3.x is okay (either from OS X or brewed):
+    # <pre># If any Python >= 2.7 < 3.x is okay (either from macOS or brewed):
     # depends_on :python</pre>
     # <pre># to depend on Python >= 2.7 but use system Python where possible
     # depends_on :python if MacOS.version <= :snow_leopard</pre>
@@ -2117,8 +2117,8 @@ class Formula
     # add the necessary includes and libs (etc.) during the brewing of that
     # other formula. But generally, keg_only formulae are not in your PATH
     # and not seen by compilers if you build your own software outside of
-    # Homebrew. This way, we don't shadow software provided by OS X.
-    # <pre>keg_only :provided_by_osx</pre>
+    # Homebrew. This way, we don't shadow software provided by macOS.
+    # <pre>keg_only :provided_by_macos</pre>
     # <pre>keg_only "because I want it so"</pre>
     def keg_only(reason, explanation = "")
       @keg_only_reason = KegOnlyReason.new(reason, explanation)
diff --git a/Library/Homebrew/manpages/brew.1.md.erb b/Library/Homebrew/manpages/brew.1.md.erb
index d6828e9d032565fd37ea1070eacd40848ea21c01..bb6a15261aa7c58f0c7a5316f57585fcc96d98e0 100644
--- a/Library/Homebrew/manpages/brew.1.md.erb
+++ b/Library/Homebrew/manpages/brew.1.md.erb
@@ -9,7 +9,7 @@
 #
 # When done, regenerate the man page and its HTML version by running `brew man`.
 %>
-brew(1) -- The missing package manager for OS X
+brew(1) -- The missing package manager for macOS
 ===============================================
 
 ## SYNOPSIS
@@ -20,7 +20,7 @@ brew(1) -- The missing package manager for OS X
 ## DESCRIPTION
 
 Homebrew is the easiest and most flexible way to install the UNIX tools Apple
-didn't include with OS X.
+didn't include with macOS.
 
 ## ESSENTIAL COMMANDS
 
@@ -220,7 +220,7 @@ can take several different forms:
   * `HOMEBREW_TEMP`:
     If set, instructs Homebrew to use `HOMEBREW_TEMP` as the temporary directory
     for building packages. This may be needed if your system temp directory and
-    Homebrew Prefix are on different volumes, as OS X has trouble moving
+    Homebrew Prefix are on different volumes, as macOS has trouble moving
     symlinks across volumes when the target does not yet exist.
 
     This issue typically occurs when using FileVault or custom SSD
diff --git a/Library/Homebrew/os/mac.rb b/Library/Homebrew/os/mac.rb
index 803d8cce3c90426ddd51607ec08d5ba0caf9e5f3..c6fb9b72155aad35ca0343c60d2d3ab2bb7deea9 100644
--- a/Library/Homebrew/os/mac.rb
+++ b/Library/Homebrew/os/mac.rb
@@ -24,7 +24,7 @@ module OS
     # This can be compared to numerics, strings, or symbols
     # using the standard Ruby Comparable methods.
     def full_version
-      @full_version ||= Version.new(ENV["HOMEBREW_OSX_VERSION"].chomp)
+      @full_version ||= Version.new(ENV["HOMEBREW_MACOS_VERSION"].chomp)
     end
 
     def prerelease?
diff --git a/Library/Homebrew/os/mac/xcode.rb b/Library/Homebrew/os/mac/xcode.rb
index c03b91f2166479cb0bd9d4f967aad8f53be66ef8..f487a69978a0d2ab54c197503f42180e7fff9af5 100644
--- a/Library/Homebrew/os/mac/xcode.rb
+++ b/Library/Homebrew/os/mac/xcode.rb
@@ -18,11 +18,11 @@ module OS
         when "10.11" then "7.3.1"
         when "10.12" then "8.0"
         else
-          # Default to newest known version of Xcode for unreleased OSX versions.
+          # Default to newest known version of Xcode for unreleased macOS versions.
           if OS::Mac.prerelease?
             "8.0"
           else
-            raise "OS X '#{MacOS.version}' is invalid"
+            raise "macOS '#{MacOS.version}' is invalid"
           end
         end
       end
diff --git a/Library/Homebrew/requirements/maximum_macos_requirement.rb b/Library/Homebrew/requirements/maximum_macos_requirement.rb
index ad60af0637669f5c022ae184e879a9d501902a4e..ceaa5184bce0a1b0c4af45347741646c0069c0f0 100644
--- a/Library/Homebrew/requirements/maximum_macos_requirement.rb
+++ b/Library/Homebrew/requirements/maximum_macos_requirement.rb
@@ -12,7 +12,7 @@ class MaximumMacOSRequirement < Requirement
 
   def message
     <<-EOS.undent
-      This formula either does not compile or function as expected on OS X
+      This formula either does not compile or function as expected on macOS
       versions newer than #{@version.pretty_name} due to an upstream incompatibility.
     EOS
   end
diff --git a/Library/Homebrew/requirements/minimum_macos_requirement.rb b/Library/Homebrew/requirements/minimum_macos_requirement.rb
index f128a661516776e12ed3f28e0785519613341bb6..8f82001ea13f23123de6711277e2f57d96f737fc 100644
--- a/Library/Homebrew/requirements/minimum_macos_requirement.rb
+++ b/Library/Homebrew/requirements/minimum_macos_requirement.rb
@@ -11,6 +11,6 @@ class MinimumMacOSRequirement < Requirement
   satisfy(build_env: false) { MacOS.version >= @version }
 
   def message
-    "OS X #{@version.pretty_name} or newer is required."
+    "macOS #{@version.pretty_name} or newer is required."
   end
 end
diff --git a/Library/Homebrew/requirements/python_requirement.rb b/Library/Homebrew/requirements/python_requirement.rb
index 478f6286e13be842f28b2fb870825cd189909e84..5d79f2a1867df90de5564aa622dd373950b7ebde 100644
--- a/Library/Homebrew/requirements/python_requirement.rb
+++ b/Library/Homebrew/requirements/python_requirement.rb
@@ -10,7 +10,7 @@ class PythonRequirement < Requirement
     next unless python
     version = python_short_version
     next unless version
-    # Always use Python 2.7 for consistency on older versions of OSX.
+    # Always use Python 2.7 for consistency on older versions of Mac OS X.
     version == Version.create("2.7")
   end
 
diff --git a/Library/Homebrew/requirements/unsigned_kext_requirement.rb b/Library/Homebrew/requirements/unsigned_kext_requirement.rb
index f57be65775b2ba4cfd86b986d8720cbdae80e4d8..2ffc8fda35178872054b945a21192c09403c412d 100644
--- a/Library/Homebrew/requirements/unsigned_kext_requirement.rb
+++ b/Library/Homebrew/requirements/unsigned_kext_requirement.rb
@@ -8,7 +8,7 @@ class UnsignedKextRequirement < Requirement
   def message
     s = <<-EOS.undent
       Building this formula from source isn't possible due to OS X
-      Yosemite and above's strict unsigned kext ban.
+      Yosemite (10.10) and above's strict unsigned kext ban.
     EOS
     s += super
     s
diff --git a/Library/Homebrew/shims/super/cc b/Library/Homebrew/shims/super/cc
index ea602f1f99627aae8e3466b3a51c690058155016..1da8ff173b4e395cf141b47383e713665fcf0f30 100755
--- a/Library/Homebrew/shims/super/cc
+++ b/Library/Homebrew/shims/super/cc
@@ -181,7 +181,7 @@ class Cmd
       args << "-Wl,-undefined,dynamic_lookup"
     when /^-isysroot/, /^--sysroot/
       sdk = enum.next
-      # We set the sysroot for OS X SDKs
+      # We set the sysroot for macOS SDKs
       args << "-isysroot" << sdk unless sdk.downcase.include? "osx"
     when "-dylib"
       args << "-Wl,#{arg}"
diff --git a/Library/Homebrew/software_spec.rb b/Library/Homebrew/software_spec.rb
index f935d9a13a148cd0f69c164f4c383ed99219c6ad..986dc5354d64e538e99a0e3778e1c4082f09f822 100644
--- a/Library/Homebrew/software_spec.rb
+++ b/Library/Homebrew/software_spec.rb
@@ -337,18 +337,18 @@ class BottleSpecification
   def checksums
     checksums = {}
     os_versions = collector.keys
-    os_versions.map! do |osx|
+    os_versions.map! do |macos|
       begin
-        MacOS::Version.from_symbol osx
+        MacOS::Version.from_symbol macos
       rescue
         nil
       end
     end.compact!
     os_versions.sort.reverse_each do |os_version|
-      osx = os_version.to_sym
-      checksum = collector[osx]
+      macos = os_version.to_sym
+      checksum = collector[macos]
       checksums[checksum.hash_type] ||= []
-      checksums[checksum.hash_type] << { checksum => osx }
+      checksums[checksum.hash_type] << { checksum => macos }
     end
     checksums
   end
diff --git a/Library/Homebrew/system_config.rb b/Library/Homebrew/system_config.rb
index 830c9ec335515dc9c2fb6a2b9a6face2c1fbc3db..a8b4ee1ff2c29f3b8382e8a01a9f115bd932377f 100644
--- a/Library/Homebrew/system_config.rb
+++ b/Library/Homebrew/system_config.rb
@@ -108,7 +108,7 @@ class SystemConfig
     end
 
     def describe_java
-      # java_home doesn't exist on all OS Xs; it might be missing on older versions.
+      # java_home doesn't exist on all macOSs; it might be missing on older versions.
       return "N/A" unless File.executable? "/usr/libexec/java_home"
 
       java_xml = Utils.popen_read("/usr/libexec/java_home", "--xml", "--failfast")
diff --git a/Library/Homebrew/test/test_formula_support.rb b/Library/Homebrew/test/test_formula_support.rb
index 111b509ec279e07ac70a84c5ff109354918d69a6..c0a79f950c0565ae153f57ee431ccbb7fc59ce08 100644
--- a/Library/Homebrew/test/test_formula_support.rb
+++ b/Library/Homebrew/test/test_formula_support.rb
@@ -8,8 +8,8 @@ class KegOnlyReasonTests < Homebrew::TestCase
   end
 
   def test_to_s_no_explanation
-    r = KegOnlyReason.new :provided_by_osx, ""
-    assert_match(/^OS X already provides/, r.to_s)
+    r = KegOnlyReason.new :provided_by_macos, ""
+    assert_match(/^macOS already provides/, r.to_s)
   end
 end
 
diff --git a/Library/Homebrew/test/test_integration_cmds.rb b/Library/Homebrew/test/test_integration_cmds.rb
index 43b8689af2c3a08479d96b3d23e9332db81cffcd..11eb6c69d816ed6abc8b7836a736f1e0bbcd3934 100644
--- a/Library/Homebrew/test/test_integration_cmds.rb
+++ b/Library/Homebrew/test/test_integration_cmds.rb
@@ -44,8 +44,8 @@ class IntegrationCommandTests < Homebrew::TestCase
     end
   end
 
-  def needs_osx
-    skip "Not on OS X" unless OS.mac?
+  def needs_macos
+    skip "Not on MacOS" unless OS.mac?
   end
 
   def cmd_id_from_args(args)
@@ -729,14 +729,14 @@ class IntegrationCommandTests < Homebrew::TestCase
 
   def test_cask
     needs_test_cmd_taps
-    needs_osx
+    needs_macos
     setup_remote_tap("caskroom/cask")
     cmd("cask", "list")
   end
 
   def test_services
     needs_test_cmd_taps
-    needs_osx
+    needs_macos
     setup_remote_tap("homebrew/services")
     assert_equal "Warning: No services available to control with `brew services`",
       cmd("services", "list")
diff --git a/Library/Homebrew/test/test_os_mac_diagnostic.rb b/Library/Homebrew/test/test_os_mac_diagnostic.rb
index f7d43c4c709727ec231048e8f638eaf189a38a33..655aa1d46b5a64c19d608960696a21acfff39cc1 100644
--- a/Library/Homebrew/test/test_os_mac_diagnostic.rb
+++ b/Library/Homebrew/test/test_os_mac_diagnostic.rb
@@ -19,11 +19,11 @@ class OSMacDiagnosticChecksTest < Homebrew::TestCase
       @checks.check_for_other_package_managers
   end
 
-  def test_check_for_unsupported_osx
+  def test_check_for_unsupported_macos
     ARGV.stubs(:homebrew_developer?).returns false
     OS::Mac.stubs(:prerelease?).returns true
     assert_match "We do not provide support for this pre-release version.",
-      @checks.check_for_unsupported_osx
+      @checks.check_for_unsupported_macos
   end
 
   def test_check_for_unsupported_curl_vars
diff --git a/Library/Homebrew/utils/analytics.sh b/Library/Homebrew/utils/analytics.sh
index b37cd3e8e7b2af9a8204f5f2273cc5bd1b86fe07..0bc58c0be5ea384218c37e347080c3f1bdc8b1ea 100644
--- a/Library/Homebrew/utils/analytics.sh
+++ b/Library/Homebrew/utils/analytics.sh
@@ -38,7 +38,7 @@ setup-analytics() {
     if [[ -n "$HOMEBREW_LINUX" ]]
     then
       HOMEBREW_ANALYTICS_USER_UUID="$(tr a-f A-F </proc/sys/kernel/random/uuid)"
-    elif [[ -n "$HOMEBREW_OSX" ]]
+    elif [[ -n "$HOMEBREW_MACOS" ]]
     then
       HOMEBREW_ANALYTICS_USER_UUID="$(/usr/bin/uuidgen)"
     else
diff --git a/Library/Homebrew/utils/github.rb b/Library/Homebrew/utils/github.rb
index 9431fa15faf40cd42722467dc7ed2e8468316941..654272363e2c7c89f907d04827a8dad3314c8763 100644
--- a/Library/Homebrew/utils/github.rb
+++ b/Library/Homebrew/utils/github.rb
@@ -33,7 +33,7 @@ module GitHub
         EOS
       else
         message << <<-EOS.undent
-          The GitHub credentials in the OS X keychain may be invalid.
+          The GitHub credentials in the macOS keychain may be invalid.
           Clear them with:
             printf "protocol=https\\nhost=github.com\\n" | git credential-osxkeychain erase
           Or create a personal access token:
@@ -103,7 +103,7 @@ module GitHub
         case GitHub.api_credentials_type
         when :keychain
           onoe <<-EOS.undent
-            Your OS X keychain GitHub credentials do not have sufficient scope!
+            Your macOS keychain GitHub credentials do not have sufficient scope!
             Scopes they have: #{credentials_scopes}
             Create a personal access token: https://github.com/settings/tokens
             and then set HOMEBREW_GITHUB_API_TOKEN as the authentication method instead.
diff --git a/Library/Homebrew/utils/ruby.sh b/Library/Homebrew/utils/ruby.sh
index 81bc16835f06fd65396255d22f3239d0c6465cfd..6945c068bbcc222e43ceacbe8c193a9746616d80 100644
--- a/Library/Homebrew/utils/ruby.sh
+++ b/Library/Homebrew/utils/ruby.sh
@@ -27,7 +27,7 @@ setup-ruby-path() {
         fi
       fi
     else
-      if [[ -n "$HOMEBREW_OSX" ]]
+      if [[ -n "$HOMEBREW_MACOS" ]]
       then
         HOMEBREW_RUBY_PATH="/System/Library/Frameworks/Ruby.framework/Versions/Current/usr/bin/ruby"
       else
diff --git a/share/doc/homebrew/Acceptable-Formulae.md b/share/doc/homebrew/Acceptable-Formulae.md
index 366615ed857728b023c14550ed4674a18ef54da3..15e8003366a7a58eaf60c72e1100c280dfd3135d 100644
--- a/share/doc/homebrew/Acceptable-Formulae.md
+++ b/share/doc/homebrew/Acceptable-Formulae.md
@@ -5,19 +5,19 @@ additional [Interesting Taps & Forks](Interesting-Taps-&-Forks.md) and anyone ca
 own!
 
 ### We try hard to avoid dupes in Homebrew/homebrew
-Stuff that comes with OS X or libraries that are provided by
+Stuff that comes with macOS or libraries that are provided by
 [RubyGems, CPAN or PyPi](Gems,-Eggs-and-Perl-Modules.md)
 should not be duplicated. There are good reasons for this:
 
 * Duplicate libraries regularly break builds
 * Subtle bugs emerge with duplicate libraries, and to a lesser extent,
   duplicate tools
-* We want our formulae to work with what comes with OS X
+* We want our formulae to work with what comes with macOS
 
 There are exceptions:
 
-* OpenSSL - Apple has formally deprecated OpenSSL on OS X in favour of their own Security Framework
-  & consequently the OS X OpenSSL is rarely updated and frequently falls behind important security updates.
+* OpenSSL - Apple has formally deprecated OpenSSL on macOS in favour of their own Security Framework
+  & consequently the macOS OpenSSL is rarely updated and frequently falls behind important security updates.
   Homebrew endeavours to use our shipped OpenSSL as much
    as possible.
 * Programs that a user will regularly interact with directly, like editors and
@@ -32,13 +32,13 @@ There are exceptions:
   Formula         | Reason
   ---             | ---
   ruby, python, perl    | People want newer versions
-  bash            | OS X's bash is stuck at 3.2 because newer versions are licensed under GPLv3
+  bash            | macOS's bash is stuck at 3.2 because newer versions are licensed under GPLv3
   zsh             | This was a mistake, but it’s too late to remove it
   emacs, vim      | [Too popular to move to dupes](https://github.com/Homebrew/homebrew/pull/21594#issuecomment-21968819)
   subversion      | Originally added for 10.5, but people want the latest version
-  libcurl         | Some formulae require a newer version than OS X provides
-  openssl         | OS X's openssl is deprecated & outdated.
-  libxml2         | Historically, OS X's libxml2 has been buggy
+  libcurl         | Some formulae require a newer version than macOS provides
+  openssl         | macOS's openssl is deprecated & outdated.
+  libxml2         | Historically, macOS's libxml2 has been buggy
 
 We also maintain [a tap](https://github.com/Homebrew/homebrew-dupes) that
 contains many duplicates not otherwise found in Homebrew.
@@ -104,7 +104,7 @@ Please trust that we need to use our discretion based on our experience
 running a package manager.
 
 ### Stuff that builds an .app
-Don’t make your formula build an `.app` (native OS X Application); we
+Don’t make your formula build an `.app` (native macOS Application); we
 don’t want those things in Homebrew (but
 [Homebrew Cask](https://github.com/caskroom/homebrew-cask) does).
 Make it build a command-line tool or a library.
diff --git a/share/doc/homebrew/Analytics.md b/share/doc/homebrew/Analytics.md
index 1346e767bac1958d9ac1258a20e7ce5f337225a4..83386b3eea7db5c74909e2aeeab297c2dc5ae8e7 100644
--- a/share/doc/homebrew/Analytics.md
+++ b/share/doc/homebrew/Analytics.md
@@ -5,12 +5,12 @@ Homebrew has begun gathering anonymous aggregate user behaviour analytics and re
 Homebrew is provided free of charge and run entirely by volunteers in their spare time. As a result, we do not have the resources to do detailed user studies of Homebrew users to decide on how best to design future features and prioritise current work. Anonymous aggregate user analytics allow us to prioritise fixes and features based on how, where and when people use Homebrew. For example:
 
 - if a formula is widely used and is failing often it will enable us to prioritise fixing that formula over others.
-- collecting the OS version allows us to decide what versions of OS X to prioritise and support and identify build failures that occur only on single versions.
+- collecting the OS version allows us to decide what versions of macOS to prioritise and support and identify build failures that occur only on single versions.
 
 ## What?
 Homebrew's analytics record some shared information for every event:
 
-- The Homebrew user agent e.g. `Homebrew/0.9.9 (Macintosh; Intel Mac OS X 10.11.4) curl/7.43.0`
+- The Homebrew user agent e.g. `Homebrew/0.9.9 (Macintosh; Intel macOS 10.12.0) curl/7.43.0`
 - The Google Analytics version i.e. `1` (https://developers.google.com/analytics/devguides/collection/protocol/v1/parameters#v)
 - The Homebrew analytics tracking ID e.g. `UA-75654628-1` (https://developers.google.com/analytics/devguides/collection/protocol/v1/parameters#tid)
 - A Homebrew analytics user ID e.g. `1BAB65CC-FE7F-4D8C-AB45-B7DB5A6BA9CB`. This is generated by `uuidgen` and stored in the repository-specific Git configuration variable `homebrew.analyticsuuid` within `$(brew --repository)/.git/config`. This does not allow us to track individual users but does enable us to accurately measure user counts vs. event counts (https://developers.google.com/analytics/devguides/collection/protocol/v1/parameters#cid)
@@ -22,8 +22,8 @@ Homebrew's analytics record some shared information for every event:
 Homebrew's analytics records the following different events:
 
 - a `screenview` hit type with the official Homebrew command you have run (with arguments stripped) e.g. `brew list` (not `brew list foo` or any external commands except `bundle` and `services`)
-- an `event` hit type with the `install` event category, the Homebrew formula from a non-private GitHub tap you have requested to install and any used options e.g. `wget --with-pcre` as the action and an event label e.g. `Mac OS X 10.11, non-/usr/local, CI` to indicate the OS version, non-standard installation location and invocation as part of CI. This allows us to identify formulae that need fixed and where more easily.
-- an `event` hit type with the `BuildError` event category, the Homebrew formula that failed to install e.g. `wget` as the action and an event label e.g. `Mac OS X 10.11`
+- an `event` hit type with the `install` event category, the Homebrew formula from a non-private GitHub tap you have requested to install and any used options e.g. `wget --with-pcre` as the action and an event label e.g. `macOS 10.12, non-/usr/local, CI` to indicate the OS version, non-standard installation location and invocation as part of CI. This allows us to identify formulae that need fixed and where more easily.
+- an `event` hit type with the `BuildError` event category, the Homebrew formula that failed to install e.g. `wget` as the action and an event label e.g. `macOS 10.12`
 - an `exception` hit type with the `exception` event category, exception description of the exception name e.g. `FormulaUnavailableError` and whether the exception was fatal e.g. `1`
 
 You can also view all the information that is sent by Homebrew's analytics by setting `HOMEBREW_ANALYTICS_DEBUG=1` in your environment. Please note this will also stop any analytics being sent.
diff --git a/share/doc/homebrew/Bottles.md b/share/doc/homebrew/Bottles.md
index a72ba51edcdf6aa7ba9d7c8a89c1ac1aceef7deb..196b36e1fbcf9c9dd3ecaec094177ba716440d39 100644
--- a/share/doc/homebrew/Bottles.md
+++ b/share/doc/homebrew/Bottles.md
@@ -56,7 +56,7 @@ Optionally contains the rebuild version of the bottle.
 Sometimes bottles may need be updated without bumping the version of the formula e.g. a new patch was applied. In that case the rebuild will have a value of 1 or more.
 
 ### `sha256`
-Contains the SHA-256 of bottle for a particular version of OS X.
+Contains the SHA-256 of bottle for a particular version of macOS.
 
 ## Formula DSL
 Additionally there is a method available in the formula DSL.
diff --git a/share/doc/homebrew/Common-Issues.md b/share/doc/homebrew/Common-Issues.md
index 70da9934561066b32d5f79814a20c838cc03e11c..320ad6d89ae9ba3749d44a9b26d9820e35faca89 100644
--- a/share/doc/homebrew/Common-Issues.md
+++ b/share/doc/homebrew/Common-Issues.md
@@ -10,7 +10,7 @@ You cloned with git, and your git configuration is set to use Windows line endin
 
 
 ### Ruby `bad interpreter: /usr/bin/ruby`
-You don't have a `/usr/bin/ruby` or it is not executable. It's not recommended to let this persist, you'd be surprised how many .apps, tools and scripts expect your OS X provided files and directories to be *unmodified* since OS X was installed.
+You don't have a `/usr/bin/ruby` or it is not executable. It's not recommended to let this persist, you'd be surprised how many .apps, tools and scripts expect your macOS provided files and directories to be *unmodified* since macOS was installed.
 
 ### `brew update` complains about untracked working tree files
 After running `brew update`, you receive a git error warning about untracked files or local changes that would be overwritten by a checkout or merge, followed by a list of files inside your Homebrew installation.
@@ -38,7 +38,7 @@ invalid multibyte escape: /^\037\235/
 
 In the past, Homebrew assumed that `/usr/bin/ruby` was Ruby 1.8. On OS X 10.9, it is now Ruby 2.0. There are various incompatibilities between the two versions, so if you upgrade to OS X 10.9 while using a sufficiently old version of Homebrew, you will encounter errors.
 
-The incompatibilities have been addressed in more recent versions of Homebrew, and it does not make assumptions about `/usr/bin/ruby`, instead it uses the executable inside OS X's Ruby framework or a vendored Ruby.
+The incompatibilities have been addressed in more recent versions of Homebrew, and it does not make assumptions about `/usr/bin/ruby`, instead it uses the executable inside MacOS's Ruby framework or a vendored Ruby.
 
 To recover from this situation, do the following:
 
@@ -118,14 +118,14 @@ Don't follow the advice here but fix by using
 `Language::Python.setup_install_args` in the formula as described in
 [Python for Formula Authors](Python-for-Formula-Authors.md).
 
-### Upgrading OS X
+### Upgrading macOS
 
-Upgrading OS X can cause errors like the following:
+Upgrading macOS can cause errors like the following:
 
 - `dyld: Library not loaded: /usr/local/opt/icu4c/lib/libicui18n.54.dylib`
 - `configure: error: Cannot find libz`
 
-Following an OS X upgrade it may be necessary to reinstall the Xcode Command Line Tools and `brew upgrade` all installed formula:
+Following an macOS upgrade it may be necessary to reinstall the Xcode Command Line Tools and `brew upgrade` all installed formula:
 
 ```bash
 xcode-select --install
diff --git a/share/doc/homebrew/FAQ.md b/share/doc/homebrew/FAQ.md
index 3c703692dd3393612946c12912db8649932d2bc6..2f6d4f9eac7ebb8890da4e766ea26ea9fcb594b1 100644
--- a/share/doc/homebrew/FAQ.md
+++ b/share/doc/homebrew/FAQ.md
@@ -71,7 +71,7 @@ Be careful as this is a destructive operation.
 Which is usually: `~/Library/Caches/Homebrew`
 
 ### My Mac `.app`s don’t find `/usr/local/bin` utilities!
-GUI apps on OS X don’t have `/usr/local/bin` in their `PATH` by default.
+GUI apps on macOS don’t have `/usr/local/bin` in their `PATH` by default.
 If you’re on Mountain Lion, you can fix this by running
 `launchctl setenv PATH "/usr/local/bin:$PATH"`. [More details
 here](https://stackoverflow.com/questions/135688/setting-environment-variables-in-os-x/5444960#5444960),
diff --git a/share/doc/homebrew/Formula-Cookbook.md b/share/doc/homebrew/Formula-Cookbook.md
index 56d566809eec694a3371a45ec395e2206d5b1d83..876a6645fcc6e7f8042d0e2f52a14919ebeb6ba0 100644
--- a/share/doc/homebrew/Formula-Cookbook.md
+++ b/share/doc/homebrew/Formula-Cookbook.md
@@ -88,7 +88,7 @@ Check the package’s `README`. Does the package install with `./configure`, `cm
 
 ## Check for dependencies
 
-The `README` probably tells you about dependencies and Homebrew or OS X probably already has them. You can check for Homebrew dependencies with `brew search`. Some common dependencies that OS X comes with:
+The `README` probably tells you about dependencies and Homebrew or macOS probably already has them. You can check for Homebrew dependencies with `brew search`. Some common dependencies that macOS comes with:
 
 * `libexpat`
 * `libGL`
@@ -394,7 +394,7 @@ end
 
 Make sure you modify `s`! This block ignores the returned value.
 
-`inreplace` should be used instead of patches when it is patching something that will never be accepted upstream e.g. make the software’s build system respect Homebrew’s installation hierarchy. If it's something that affects both Homebrew and MacPorts (i.e. OS X specific) it should be turned into an upstream submitted patch instead.
+`inreplace` should be used instead of patches when it is patching something that will never be accepted upstream e.g. make the software’s build system respect Homebrew’s installation hierarchy. If it's something that affects both Homebrew and MacPorts (i.e. macOS specific) it should be turned into an upstream submitted patch instead.
 
 If you need modify variables in a `Makefile`, rather than using `inreplace`, pass them as arguments to `make`:
 
diff --git a/share/doc/homebrew/Gems,-Eggs-and-Perl-Modules.md b/share/doc/homebrew/Gems,-Eggs-and-Perl-Modules.md
index 3f2159bc86d4936f7a50eb7afa8edc0567e5ad52..dfbdc224f0b6cafd91efd45074e436f67e648f31 100644
--- a/share/doc/homebrew/Gems,-Eggs-and-Perl-Modules.md
+++ b/share/doc/homebrew/Gems,-Eggs-and-Perl-Modules.md
@@ -1,5 +1,5 @@
 # Gems, Eggs and Perl Modules
-On a fresh OS X installation there are three empty directories for
+On a fresh macOS installation there are three empty directories for
 add-ons available to all users:
 
     /Library/Ruby
@@ -42,7 +42,7 @@ about the paths. Note, a brewed Python still searches for modules in
 ### With system’s Python
 _This is only recommended if you **don't** use a brewed Python._
 
-On OS X, any [Python version X.Y also searches in
+On macOS, any [Python version X.Y also searches in
 `~/Library/Python/X.Y/lib/python/site-packages` for
 modules](https://docs.python.org/2/install/index.html#inst-alt-install-user).
 That dir might not yet exist, but you can create it:
diff --git a/share/doc/homebrew/Homebrew-and-Python.md b/share/doc/homebrew/Homebrew-and-Python.md
index 7bb05343c8892691bca3c086908096cd1e5f9adf..5b8676dbc01dec81543526fea60d0edafc453add 100644
--- a/share/doc/homebrew/Homebrew-and-Python.md
+++ b/share/doc/homebrew/Homebrew-and-Python.md
@@ -3,7 +3,7 @@
 
 This page describes how Python is handled in Homebrew for users. See [Python for Formula Authors](Python-for-Formula-Authors.md) for advice on writing formulae to install packages written in Python.
 
-Homebrew should work with any [CPython](https://stackoverflow.com/questions/2324208/is-there-any-difference-between-cpython-and-python) and defaults to the OS X system Python.
+Homebrew should work with any [CPython](https://stackoverflow.com/questions/2324208/is-there-any-difference-between-cpython-and-python) and defaults to the macOS system Python.
 
 Homebrew provides formulae to brew a more up-to-date Python 2.7.x (and 3.x).
 
diff --git a/share/doc/homebrew/How-to-build-software-outside-Homebrew-with-Homebrew-keg-only-dependencies.md b/share/doc/homebrew/How-to-build-software-outside-Homebrew-with-Homebrew-keg-only-dependencies.md
index c22979f2264f8307eb44540113bb6077fdac67e5..f71c75164e6e303ca793727fcc4e48ab9ec14b2a 100644
--- a/share/doc/homebrew/How-to-build-software-outside-Homebrew-with-Homebrew-keg-only-dependencies.md
+++ b/share/doc/homebrew/How-to-build-software-outside-Homebrew-with-Homebrew-keg-only-dependencies.md
@@ -14,7 +14,7 @@ This is because Homebrew keeps it locked inside its individual prefix, rather th
 
 A number of people in this situation are either forcefully linking `keg_only` tools with `brew link --force` or moving default system utilities out of the `$PATH` and replacing them with manually-created symlinks to the Homebrew-provided tool.
 
-*Please* do not remove OS X native tools and forcefully replace them with symlinks back to the Homebrew-provided tool. Doing so can and likely will cause significant breakage when attempting to build software.
+*Please* do not remove macOS native tools and forcefully replace them with symlinks back to the Homebrew-provided tool. Doing so can and likely will cause significant breakage when attempting to build software.
 
 `brew link --force` creates a warning in `brew doctor` to let both you and maintainers know that link exists and could be causing issues. If you’ve linked something and there’s no problems at all? Feel free to ignore the `brew doctor` error.
 
diff --git a/share/doc/homebrew/Installation.md b/share/doc/homebrew/Installation.md
index 8c7892846ba5b306242d5a17a3bd874bfe29aeb3..be9f7ca91a59daff8bb92a87a213a658a84999d7 100644
--- a/share/doc/homebrew/Installation.md
+++ b/share/doc/homebrew/Installation.md
@@ -49,7 +49,7 @@ supported on a best-effort basis. For 10.4 and 10.5, see
 <a name="3"><sup>3</sup></a> Most formulae require a compiler. A handful
 require a full Xcode installation. You can install Xcode, the CLT, or both;
 Homebrew supports all three configurations. Downloading Xcode may require an
-Apple Developer account on older versions of OS X. Sign up for free
+Apple Developer account on older versions of Mac OS X. Sign up for free
 [here](https://developer.apple.com/register/index.action).
 
 <a name="4"><sup>4</sup></a> The one-liner installation method found on
diff --git a/share/doc/homebrew/Interesting-Taps-&-Forks.md b/share/doc/homebrew/Interesting-Taps-&-Forks.md
index 5a9c0d7ea643f13c69e4450df3cf5f8460f77674..d23277b15cf70ad47bb328b70e36b31855475bef 100644
--- a/share/doc/homebrew/Interesting-Taps-&-Forks.md
+++ b/share/doc/homebrew/Interesting-Taps-&-Forks.md
@@ -4,7 +4,7 @@ Homebrew has the capability to add (and remove) multiple taps to your local inst
 
 ## Main Taps
 
-*   [homebrew/apache](https://github.com/Homebrew/homebrew-apache): A tap for Apache modules, extending OS X's built-in Apache. These brews may require unconventional additional setup, as explained in the caveats.
+*   [homebrew/apache](https://github.com/Homebrew/homebrew-apache): A tap for Apache modules, extending macOS's built-in Apache. These brews may require unconventional additional setup, as explained in the caveats.
 
 *   [homebrew/boneyard](https://github.com/Homebrew/homebrew-boneyard): Formulae from other official taps, primarily (homebrew/core) are not deleted, they are moved here.
 
@@ -50,7 +50,7 @@ You can be added as a maintainer for one of the Homebrew organization taps and a
 
 *   [petere/postgresql](https://github.com/petere/homebrew-postgresql): Allows installing multiple PostgreSQL versions in parallel.
 
-*   [titanous/gnuradio](https://github.com/titanous/homebrew-gnuradio):  GNU Radio and friends running on OS X.
+*   [titanous/gnuradio](https://github.com/titanous/homebrew-gnuradio):  GNU Radio and friends running on macOS.
 
 ## Interesting Forks
 
diff --git a/share/doc/homebrew/Maintainer-Guidelines.md b/share/doc/homebrew/Maintainer-Guidelines.md
index 6ecf690db5010df1f01e100fb68e21a023debbec..d83118642a05e54ddd401810c1bb3fe63183d228 100644
--- a/share/doc/homebrew/Maintainer-Guidelines.md
+++ b/share/doc/homebrew/Maintainer-Guidelines.md
@@ -11,7 +11,7 @@ Maybe you were looking for the [Formula Cookbook](Formula-Cookbook.md)?
 This is all that really matters:
 - Ensure the name seems reasonable.
 - Add aliases.
-- Ensure it is not an unreasonable dupe of anything that comes with OS X.
+- Ensure it is not an unreasonable dupe of anything that comes with macOS.
 - Ensure it is not a library that can be installed with
   [gem](https://en.wikipedia.org/wiki/RubyGems),
   [cpan](https://en.wikipedia.org/wiki/Cpan) or
@@ -92,8 +92,8 @@ implemented!).
 
 ### Duplicates
 The main repository avoids duplicates as much as possible. The exception is
-libraries that OS X provides but have bugs, and the bugs are fixed in a
-newer version. Or libraries that OS X provides, but they are too old for
+libraries that macOS provides but have bugs, and the bugs are fixed in a
+newer version. Or libraries that macOS provides, but they are too old for
 some other formula. The rest should be in the `homebrew/dupes` tap.
 
 Still determine if it possible to avoid the duplicate. Be thorough. Duped
@@ -104,7 +104,7 @@ If it duplicates anything ask another maintainer first. Some dupes are okay,
 some can cause subtle issues we don’t want to have to deal with in the future.
 
 Dupes we have allowed:
--   `libxml` \<— OS X version is old and buggy
+-   `libxml` \<— macOS version is old and buggy
 -   `libpng` \<— Ditto
 
 #### Add comments
diff --git a/share/doc/homebrew/Prose-Style-Guidelines.md b/share/doc/homebrew/Prose-Style-Guidelines.md
index a06a628e7801fa4010765f806cae9541501251b8..8c4f1d1f09d7ef9988c65439b05079ac9a86a1c9 100644
--- a/share/doc/homebrew/Prose-Style-Guidelines.md
+++ b/share/doc/homebrew/Prose-Style-Guidelines.md
@@ -75,7 +75,7 @@ We prefer:
  * When abbreviating, introduce the abbreviation with the first usage in any document
 * Some abbreviations (near-universally understood among our user base) are fine, though.
  * "Mac" is fine; "Macintosh" isn't necessary
-* "OS X", not "OSX" or "MacOS"
+* "macOS" for all versions, "OS X" or "Mac OS X" when describing specific older versions
 * "RuboCop", not "Rubocop"
 * A pull request is made "on" a repository; that repository is "at" a URL
 
diff --git a/share/doc/homebrew/Troubleshooting.md b/share/doc/homebrew/Troubleshooting.md
index 31682a7bf92e97d3141e80ccf4d837f5c438d8b8..4fc77d6cd71d24b7a40744a4548966e075ae9ff9 100644
--- a/share/doc/homebrew/Troubleshooting.md
+++ b/share/doc/homebrew/Troubleshooting.md
@@ -23,4 +23,4 @@ brew gist-logs <formula>
 0. Upload debugging information to a [Gist](https://gist.github.com):
   - If you had a formula error: run `brew gist-logs <formula>` (where `<formula>` is the name of the formula that failed to build).
   - If you encountered a non-formula bug: upload the output of `brew config` and `brew doctor` to a new [Gist](https://gist.github.com).
-1. [Create a new issue](https://github.com/Homebrew/homebrew-core/issues/new) titled "\<formula name> failed to build on 10.x", where `<formula name>` is the name of the formula that failed to build, and `10.x` is the version of OS X you are using and including the link output by `brew gist-logs`
+1. [Create a new issue](https://github.com/Homebrew/homebrew-core/issues/new) titled "\<formula name> failed to build on 10.x", where `<formula name>` is the name of the formula that failed to build, and `10.x` is the version of macOS you are using and including the link output by `brew gist-logs`
diff --git a/share/doc/homebrew/Xcode.md b/share/doc/homebrew/Xcode.md
index 9af12b6abbe334784a5dcf507538eba64e7dce22..98c5c6347ca22a4b5d21c34932a5c2e15855e99e 100644
--- a/share/doc/homebrew/Xcode.md
+++ b/share/doc/homebrew/Xcode.md
@@ -3,7 +3,7 @@
 Homebrew supports and recommends the latest Xcode and/or Command Line
 Tools available for your platform:
 
- OS X  | Xcode | Command Line Tools
+ macOS  | Xcode | Command Line Tools
  ----- | ----- | ----------------------------
  10.6  | 3.2.6 | N/A
  10.7  | 4.6.3 | April 2013
diff --git a/share/doc/homebrew/brew.1.html b/share/doc/homebrew/brew.1.html
index 25be33ef32b2a1eb352b7a24aefab8951e4e50ae..6948b3f93d5f24721fa5918c916e7f3e12eb941e 100644
--- a/share/doc/homebrew/brew.1.html
+++ b/share/doc/homebrew/brew.1.html
@@ -1,7 +1,7 @@
 <div class='mp'>
 <h2 id="NAME">NAME</h2>
 <p class="man-name">
-  <code>brew</code> - <span class="man-whatis">The missing package manager for OS X</span>
+  <code>brew</code> - <span class="man-whatis">The missing package manager for macOS</span>
 </p>
 
 <h2 id="SYNOPSIS">SYNOPSIS</h2>
@@ -12,7 +12,7 @@
 <h2 id="DESCRIPTION">DESCRIPTION</h2>
 
 <p>Homebrew is the easiest and most flexible way to install the UNIX tools Apple
-didn't include with OS X.</p>
+didn't include with macOS.</p>
 
 <h2 id="ESSENTIAL-COMMANDS">ESSENTIAL COMMANDS</h2>
 
@@ -128,7 +128,7 @@ checksum of a previously cached version no longer matches.</p>
 bottle.</p>
 
 <p>If <code>--force-bottle</code> is passed, download a bottle if it exists for the current
-version of OS X, even if it would not be used during installation.</p></dd>
+version of macOS, even if it would not be used during installation.</p></dd>
 <dt><code>gist-logs</code> [<code>--new-issue</code>|<code>-n</code>] <var>formula</var></dt><dd><p>Upload logs for a failed build of <var>formula</var> to a new Gist.</p>
 
 <p><var>formula</var> is usually the name of the formula to install, but it can be specified
@@ -217,7 +217,7 @@ be linked or which would be deleted by <code>brew link --overwrite</code>, but w
 actually link or delete any files.</p>
 
 <p>If <code>--force</code> is passed, Homebrew will allow keg-only formulae to be linked.</p></dd>
-<dt><code>linkapps</code> [<code>--local</code>] [<var>formulae</var>]</dt><dd><p>Find installed formulae that provide <code>.app</code>-style OS X apps and symlink them
+<dt><code>linkapps</code> [<code>--local</code>] [<var>formulae</var>]</dt><dd><p>Find installed formulae that provide <code>.app</code>-style macOS apps and symlink them
 into <code>/Applications</code>, allowing for easier access.</p>
 
 <p>If no <var>formulae</var> are provided, all of them will have their apps symlinked.</p>
@@ -462,7 +462,7 @@ name of the file or formula being audited, to make the output easy to grep.</p>
 
 <p><code>audit</code> exits with a non-zero status if any errors are found. This is useful,
 for instance, for implementing pre-commit hooks.</p></dd>
-<dt><code>bottle</code> [<code>--verbose</code>] [<code>--no-rebuild</code>] [<code>--keep-old</code>] [<code>--skip-relocation</code>] [<code>--root-url=&lt;root_url></code>]:</dt><dd><p></p></dd>
+<dt><code>bottle</code> [<code>--verbose</code>] [<code>--no-rebuild</code>] [<code>--keep-old</code>] [<code>--skip-relocation</code>] [<code>--root-url=&lt;root_url></code>] [<code>--force-core-tap</code>]:</dt><dd><p></p></dd>
 <dt><code>bottle</code> <code>--merge</code> [<code>--no-commit</code>] [<code>--keep-old</code>] [<code>--write</code>]:</dt><dd><p></p>
 
 <p>Generate a bottle (binary package) from a formula installed with
@@ -696,7 +696,7 @@ a Homebrew-built Subversion if installed, or the system-provided binary.</p>
 <p>Set this to force Homebrew to use a particular <code>svn</code> binary.</p></dd>
 <dt><code>HOMEBREW_TEMP</code></dt><dd><p>If set, instructs Homebrew to use <code>HOMEBREW_TEMP</code> as the temporary directory
 for building packages. This may be needed if your system temp directory and
-Homebrew Prefix are on different volumes, as OS X has trouble moving
+Homebrew Prefix are on different volumes, as macOS has trouble moving
 symlinks across volumes when the target does not yet exist.</p>
 
 <p>This issue typically occurs when using FileVault or custom SSD
diff --git a/share/man/man1/brew.1 b/share/man/man1/brew.1
index 1877a39477144134a7a1bf3443571a62cd7f13b5..3cd37e64d4c3e3356fe4a8840ffb3bba3f5ec68a 100644
--- a/share/man/man1/brew.1
+++ b/share/man/man1/brew.1
@@ -4,7 +4,7 @@
 .TH "BREW" "1" "September 2016" "Homebrew" "brew"
 .
 .SH "NAME"
-\fBbrew\fR \- The missing package manager for OS X
+\fBbrew\fR \- The missing package manager for macOS
 .
 .SH "SYNOPSIS"
 \fBbrew\fR \fB\-\-version\fR
@@ -13,7 +13,7 @@
 \fBbrew\fR \fIcommand\fR [\fB\-\-verbose\fR|\fB\-v\fR] [\fIoptions\fR] [\fIformula\fR] \.\.\.
 .
 .SH "DESCRIPTION"
-Homebrew is the easiest and most flexible way to install the UNIX tools Apple didn\'t include with OS X\.
+Homebrew is the easiest and most flexible way to install the UNIX tools Apple didn\'t include with macOS\.
 .
 .SH "ESSENTIAL COMMANDS"
 For the full command list, see the \fICOMMANDS\fR section\.
@@ -171,7 +171,7 @@ If \fB\-\-deps\fR is passed, also download dependencies for any listed \fIformul
 If \fB\-\-build\-from\-source\fR is passed, download the source rather than a bottle\.
 .
 .IP
-If \fB\-\-force\-bottle\fR is passed, download a bottle if it exists for the current version of OS X, even if it would not be used during installation\.
+If \fB\-\-force\-bottle\fR is passed, download a bottle if it exists for the current version of macOS, even if it would not be used during installation\.
 .
 .TP
 \fBgist\-logs\fR [\fB\-\-new\-issue\fR|\fB\-n\fR] \fIformula\fR
@@ -291,7 +291,7 @@ If \fB\-\-force\fR is passed, Homebrew will allow keg\-only formulae to be linke
 .
 .TP
 \fBlinkapps\fR [\fB\-\-local\fR] [\fIformulae\fR]
-Find installed formulae that provide \fB\.app\fR\-style OS X apps and symlink them into \fB/Applications\fR, allowing for easier access\.
+Find installed formulae that provide \fB\.app\fR\-style macOS apps and symlink them into \fB/Applications\fR, allowing for easier access\.
 .
 .IP
 If no \fIformulae\fR are provided, all of them will have their apps symlinked\.
@@ -644,7 +644,7 @@ If \fB\-\-display\-filename\fR is passed, every line of output is prefixed with
 \fBaudit\fR exits with a non\-zero status if any errors are found\. This is useful, for instance, for implementing pre\-commit hooks\.
 .
 .TP
-\fBbottle\fR [\fB\-\-verbose\fR] [\fB\-\-no\-rebuild\fR] [\fB\-\-keep\-old\fR] [\fB\-\-skip\-relocation\fR] [\fB\-\-root\-url=<root_url>\fR]:
+\fBbottle\fR [\fB\-\-verbose\fR] [\fB\-\-no\-rebuild\fR] [\fB\-\-keep\-old\fR] [\fB\-\-skip\-relocation\fR] [\fB\-\-root\-url=<root_url>\fR] [\fB\-\-force\-core\-tap\fR]:
 
 .
 .TP
@@ -952,7 +952,7 @@ Set this to force Homebrew to use a particular \fBsvn\fR binary\.
 .
 .TP
 \fBHOMEBREW_TEMP\fR
-If set, instructs Homebrew to use \fBHOMEBREW_TEMP\fR as the temporary directory for building packages\. This may be needed if your system temp directory and Homebrew Prefix are on different volumes, as OS X has trouble moving symlinks across volumes when the target does not yet exist\.
+If set, instructs Homebrew to use \fBHOMEBREW_TEMP\fR as the temporary directory for building packages\. This may be needed if your system temp directory and Homebrew Prefix are on different volumes, as macOS has trouble moving symlinks across volumes when the target does not yet exist\.
 .
 .IP
 This issue typically occurs when using FileVault or custom SSD configurations\.
diff --git a/Library/Homebrew/formula_support.rb b/Library/Homebrew/formula_support.rb
index 83855d13178e721805261f93ebed6b5c284e0c0c..e4f80036440a423d74061b3b7e826dc6e49693e8 100644
--- a/Library/Homebrew/formula_support.rb
+++ b/Library/Homebrew/formula_support.rb
@@ -1,7 +1,7 @@
 # Used to track formulae that cannot be installed at the same time
 FormulaConflict = Struct.new(:name, :reason)
 
 # Used to annotate formulae that duplicate OS X provided software
 # or cause conflicts when linked in.
 class KegOnlyReason
   def initialize(reason, explanation)
@@ -29,22 +29,22 @@ class KegOnlyReason
   def to_s
     return @explanation unless @explanation.empty?
     case @reason
-    when :provided_by_osx then <<-EOS
-OS X already provides this software and installing another version in
+    when :provided_by_macos, :provided_by_osx then <<-EOS
+macOS already provides this software and installing another version in
 parallel can cause all kinds of trouble.
 EOS
-    when :shadowed_by_osx then <<-EOS
-OS X provides similar software and installing this software in
+    when :shadowed_by_macos, :shadowed_by_osx then <<-EOS
+macOS provides similar software and installing this software in
 parallel can cause all kinds of trouble.
 EOS
     when :provided_pre_mountain_lion then <<-EOS
-OS X already provides this software in versions before Mountain Lion.
+macOS already provides this software in versions before Mountain Lion.
 EOS
     when :provided_pre_mavericks then <<-EOS
-OS X already provides this software in versions before Mavericks.
+macOS already provides this software in versions before Mavericks.
 EOS
     when :provided_pre_el_capitan then <<-EOS
-OS X already provides this software in versions before El Capitan.
+macOS already provides this software in versions before El Capitan.
 EOS
     when :provided_until_xcode43
       "Xcode provides this software prior to version 4.3."
@@ -1,7 +1,7 @@
 FormulaConflict = Struct.new(:name, :reason)
 
-# Used to annotate formulae that duplicate OS X provided software
+# Used to annotate formulae that duplicate macOS provided software
 # or cause conflicts when linked in.
 class KegOnlyReason